@@ -20,7 +20,7 @@ from pilot.api import PilotCompute, PilotComputeService, ComputeUnit, State
 
 """ Configure coordination backend here """
 #from pilot.coordination.advert import AdvertCoordinationAdaptor as CoordinationAdaptor
-from pilot.coordination.nocoord import NoCoordinationAdaptor as CoordinationAdaptor
+from pilot.coordination.redis_adaptor import RedisCoordinationAdaptor as CoordinationAdaptor
 
 
 """ This variable defines the coordination system that is used by BigJob
@@ -30,7 +30,7 @@ from pilot.coordination.nocoord import NoCoordinationAdaptor as CoordinationAdap
         redis://localhost:6379 (Redis at localhost)
         tcp://localhost (ZMQ)
 """
-COORDINATION_URL = "advert://localhost/?dbtype=sqlite3"
+COORDINATION_URL = "redis://localhost"
 
 
 class PilotComputeService(PilotComputeService):
@@ -130,6 +130,8 @@ class PilotComputeService(PilotComputeService):
         for i in pilot_compute_description.keys():
             resource_description[i] = pilot_compute_description[i] 
         
+        resource_description["pilot_compute_description"] = pilot_compute_description
+        
         return resource_description
 
     
@@ -148,7 +150,7 @@ class PilotComputeService(PilotComputeService):
         if ("walltime" in bj_dict):
             walltime=bj_dict["walltime"]
 
-        working_directory = (os.getcwd()+"/agent")
+        working_directory = None
         if ("working_directory" in bj_dict):
             working_directory=bj_dict["working_directory"]
             
@@ -156,17 +158,18 @@ class PilotComputeService(PilotComputeService):
         if ("file_transfer" in bj_dict):
             bj_filetransfer = bj_dict["file_transfer"]
 
-        bj.start_pilot_job(gram_url,
-                           None,
-                           bj_dict["number_of_processes"],
-                           bj_dict["queue"],
-                           bj_dict["allocation"],
-                           working_directory, 
-                           None,
-                           walltime,
-                           ppn,
-                           filetransfers=bj_filetransfer,
-                           external_queue=self.coordination_queue)
+
+        bj.start_pilot_job(lrms_url = gram_url,
+                           number_nodes = bj_dict["number_of_processes"],
+                           queue = bj_dict["queue"],
+                           project = bj_dict["allocation"],
+                           working_directory = working_directory, 
+                           walltime = walltime,
+                           processes_per_node = ppn,
+                           filetransfers = bj_filetransfer,
+                           external_queue = self.coordination_queue,
+                           pilot_compute_description = bj_dict["pilot_compute_description"]
+                           )
         return bj
     
 ###############################################################################
@@ -440,7 +443,11 @@ class ComputeUnit(ComputeUnit):
         if compute_unit_description.has_key("error"): 
             jd.error = compute_unit_description["error"]
         if compute_unit_description.has_key("file_transfer"):
-            jd.file_transfer=compute_unit_description["file_transfer"]            
+            jd.file_transfer=compute_unit_description["file_transfer"]  
+        if compute_unit_description.has_key("input_data"):
+            jd.input_data=compute_unit_description["input_data"]  
+        if compute_unit_description.has_key("output_data"):
+            jd.output_data=compute_unit_description["output_data"]            
         return jd
         
         
